Modules
Macros
- functions
- Declares a group of builtin functions and exports them.
- raise
- Creates an exception wrapped in an
Errand returns it from the current function or closure.
Constants
- FILE_
EXTENSION - Files need to end with this extension to be considered by import resolution.